@@ -2,7 +2,7 @@ package App::cpm::Worker::Installer;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.300';
+our $VERSION = '0.301';
 
 use App::cpm::Logger::File;
 use App::cpm::Worker::Installer::Menlo;
@@ -274,23 +274,20 @@ sub _get_configure_requirements {
         version => $p->{$_}{version} || undef,
     }, sort keys %$p];
 
-    my $reqs = [];
+    my $requirements = [];
     if ($self->menlo->opts_in_static_install($meta)) {
         $self->menlo->{logger}->log("Distribution opts in x_static_install: $meta->{x_static_install}");
     } else {
-        $reqs = $self->_extract_requirements($meta, [qw(configure)]);
-        if (    -f "Build.PL"
-            and ($distfile || "") !~ m{/Module-Build-[0-9v]}
-            and ( !@$reqs or (@$reqs == 1 && $reqs->[0]{package} eq 'ExtUtils::MakeMaker') )
-        ) {
-            push @$reqs, {package => "Module::Build", version_range => "0.38"};
+        $requirements = $self->_extract_requirements($meta, [qw(configure)]);
+        if (!@$requirements and -f "Build.PL" and ($distfile || "") !~ m{/Module-Build-[0-9v]}) {
+            push @$requirements, {package => "Module::Build", version_range => "0.38"};
         }
 
         if (NEED_INJECT_TOOLCHAIN_REQS) {
-            $self->_inject_toolchain_reqs($distfile, $reqs);
+            $self->_inject_toolchain_reqs($distfile, $requirements);
         }
     }
-    return ($meta ? $meta->as_struct : +{}, $reqs, $provides);
+    return ($meta ? $meta->as_struct : +{}, $requirements, $provides);
 }
 
 
@@ -323,22 +320,29 @@ sub configure {
     my $menlo = $self->menlo;
 
     $menlo->{logger}->log("Configuring distribution");
-    my $static_builder;
-    if ($menlo->opts_in_static_install($meta)) {
-        my $state = {};
-        $menlo->static_install_configure($state, "dummy", 1);
-        $static_builder = $state->{static_install};
-    } elsif (-f 'Build.PL') {
-        $self->_retry(sub {
-            $menlo->configure([ $menlo->{perl}, 'Build.PL' ], 1);
-            -f 'Build';
-        }) or return;
-    } elsif (-f 'Makefile.PL') {
-        $self->_retry(sub {
-            $menlo->configure([ $menlo->{perl}, 'Makefile.PL' ], 1); # XXX depth == 1?
-            -f 'Makefile';
-        }) or return;
+    my ($static_builder, $configure_ok);
+    {
+        if ($menlo->opts_in_static_install($meta)) {
+            my $state = {};
+            $menlo->static_install_configure($state, "dummy", 1);
+            $static_builder = $state->{static_install};
+            ++$configure_ok and last;
+        }
+        if (-f 'Build.PL') {
+            $self->_retry(sub {
+                $menlo->configure([ $menlo->{perl}, 'Build.PL' ], 1);
+                -f 'Build';
+            }) and ++$configure_ok and last;
+        }
+        if (-f 'Makefile.PL') {
+            $self->_retry(sub {
+                $menlo->configure([ $menlo->{perl}, 'Makefile.PL' ], 1); # XXX depth == 1?
+                -f 'Makefile';
+            }) and ++$configure_ok and last;
+        }
     }
+    return unless $configure_ok;
+
     my $distdata = $self->_build_distdata($source, $distfile, $meta);
     my $requirements = [];
     my $phase = $self->{notest} ? [qw(build runtime)] : [qw(build test runtime)];
